require 'spec_helper'

describe SendEmailTo do
  let(:session) { Sessions::BasicAuthSession.new }
  before { allow(Sessions::BasicAuthSession).to receive(:new).and_return session }

  it 'performs a post on the emails api path providing the person_id and the email attributes' do
    email_attributes = {subject: 'some_subject',
                        body: 'some_body',
                        content_type: 'some/content/type',
                        mail_type: 'some_mail_type'}
    expect(session).to receive(:post).with '/emails', person_id: 'some_person_id', email: email_attributes
    SendEmailTo.run!(person_id: 'some_person_id', attributes: email_attributes)
  end

  it 'defaults the content_type to text/html' do
    email_attributes = {subject: 'some_subject',
                        body: 'some_body',
                        mail_type: 'some_mail_type'}
    expect(session).to receive(:post).with '/emails', person_id: 'some_person_id',
                                                      email: email_attributes.merge(content_type: 'text/html')
    SendEmailTo.run!(person_id: 'some_person_id', attributes: email_attributes)
  end
end
